pub fn reduce_positions(
source: &mut impl BoundedSpatialRecordSource,
) -> RecordsResult<PositionReduction>Expand description
Consumes a source and computes bounds and centroid without retaining chunks.
pub fn reduce_positions(
source: &mut impl BoundedSpatialRecordSource,
) -> RecordsResult<PositionReduction>Consumes a source and computes bounds and centroid without retaining chunks.